@@ -100,6 +100,9 @@ typedef enum {
 /* Disable SameSite Environment Value */
 #define AM_DISABLE_SAMESITE_ENV_VAR "MELLON_DISABLE_SAMESITE"
 
+/* Force setting SameSite to None */
+#define AM_FORCE_SAMESITE_NONE_NOTE "MELLON_FORCE_SAMESITE_NONE"
+
 
 /* This is the length of the id we use (for session IDs and
  * replaying POST data).
@@ -276,6 +279,9 @@ typedef struct am_dir_cfg_rec {
     /* Maximum number of seconds a session is valid for. */
     int session_length;
 
+    /* Maximum number of seconds a session idle timeout is valid for. */
+    int session_idle_timeout;
+
     /* No cookie error page. */
     const char *no_cookie_error_page;
 
@@ -324,6 +330,10 @@ typedef struct am_dir_cfg_rec {
 
     /* Enabled the session invalidate endpoint. */
     int enabled_invalidation_session;
+
+    /* Send Expect Header. */
+    int send_expect_header;
+
 } am_dir_cfg_rec;
 
 /* Bitmask for PAOS service options */
@@ -359,6 +369,7 @@ typedef struct am_cache_entry_t {
     am_cache_storage_t cookie_token;
     apr_time_t access;
     apr_time_t expires;
+    apr_time_t idle_timeout;
     int logged_in;
     unsigned short size;
     am_cache_storage_t user;
@@ -379,7 +390,8 @@ typedef struct am_cache_entry_t {
 
 typedef enum { 
     AM_CACHE_SESSION, 
-    AM_CACHE_NAMEID 
+    AM_CACHE_NAMEID,
+    AM_CACHE_ASSERTIONID
 } am_cache_key_t;
 
 /* Type for configuring environment variable names */
@@ -463,6 +475,7 @@ am_cache_entry_t *am_cache_new(request_rec *r,
 void am_cache_unlock(request_rec *r, am_cache_entry_t *entry);
 
 void am_cache_update_expires(request_rec *r, am_cache_entry_t *t, apr_time_t expires);
+void am_cache_update_idle_timeout(request_rec *r, am_cache_entry_t *t, int session_idle_timeout);
 
 void am_cache_env_populate(request_rec *r, am_cache_entry_t *session);
 int am_cache_env_append(am_cache_entry_t *session,
@@ -482,6 +495,8 @@ const char *am_cache_get_lasso_session(am_cache_entry_t *session);
 am_cache_entry_t *am_get_request_session(request_rec *r);
 am_cache_entry_t *am_get_request_session_by_nameid(request_rec *r, 
                                                    char *nameid);
+am_cache_entry_t *am_get_request_session_by_assertionid(request_rec *r,
+                                                        char *assertionid);
 am_cache_entry_t *am_new_request_session(request_rec *r);
 void am_release_request_session(request_rec *r, am_cache_entry_t *session);
 void am_delete_request_session(request_rec *r, am_cache_entry_t *session);
